package com.ruoyi.change.mapper;

import java.util.List;
import com.ruoyi.change.domain.TbAssetAllocation;

/**
 * 资产调拨Mapper接口
 * 
 * @author 原动力
 * @date 2023-05-15
 */
public interface TbAssetAllocationMapper 
{
    /**
     * 查询资产调拨
     * 
     * @param id 资产调拨主键
     * @return 资产调拨
     */
    public TbAssetAllocation selectTbAssetAllocationById(Long id);

    /**
     * 查询资产调拨列表
     * 
     * @param tbAssetAllocation 资产调拨
     * @return 资产调拨集合
     */
    public List<TbAssetAllocation> selectTbAssetAllocationList(TbAssetAllocation tbAssetAllocation);

    /**
     * 新增资产调拨
     * 
     * @param tbAssetAllocation 资产调拨
     * @return 结果
     */
    public int insertTbAssetAllocation(TbAssetAllocation tbAssetAllocation);

    /**
     * 修改资产调拨
     * 
     * @param tbAssetAllocation 资产调拨
     * @return 结果
     */
    public int updateTbAssetAllocation(TbAssetAllocation tbAssetAllocation);

    /**
     * 删除资产调拨
     * 
     * @param id 资产调拨主键
     * @return 结果
     */
    public int deleteTbAssetAllocationById(Long id);

    /**
     * 批量删除资产调拨
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbAssetAllocationByIds(Long[] ids);
}
