package com.ruoyi.change.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.change.domain.TbAssetAllocation;
import com.ruoyi.change.service.ITbAssetAllocationService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资产调拨Controller
 * 
 * @author 原动力
 * @date 2023-05-15
 */
@RestController
@RequestMapping("/change/allocation")
public class TbAssetAllocationController extends BaseController
{
    @Autowired
    private ITbAssetAllocationService tbAssetAllocationService;

    /**
     * 查询资产调拨列表
     */
    @PreAuthorize("@ss.hasPermi('change:allocation:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbAssetAllocation tbAssetAllocation)
    {
        startPage();
        List<TbAssetAllocation> list = tbAssetAllocationService.selectTbAssetAllocationList(tbAssetAllocation);
        return getDataTable(list);
    }

    /**
     * 导出资产调拨列表
     */
    @PreAuthorize("@ss.hasPermi('change:allocation:export')")
    @Log(title = "资产调拨", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbAssetAllocation tbAssetAllocation)
    {
        List<TbAssetAllocation> list = tbAssetAllocationService.selectTbAssetAllocationList(tbAssetAllocation);
        ExcelUtil<TbAssetAllocation> util = new ExcelUtil<TbAssetAllocation>(TbAssetAllocation.class);
        util.exportExcel(response, list, "资产调拨数据");
    }

    /**
     * 获取资产调拨详细信息
     */
    @PreAuthorize("@ss.hasPermi('change:allocation:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tbAssetAllocationService.selectTbAssetAllocationById(id));
    }

    /**
     * 新增资产调拨
     */
    @PreAuthorize("@ss.hasPermi('change:allocation:add')")
    @Log(title = "资产调拨", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbAssetAllocation tbAssetAllocation)
    {
        return toAjax(tbAssetAllocationService.insertTbAssetAllocation(tbAssetAllocation));
    }

    /**
     * 修改资产调拨
     */
    @PreAuthorize("@ss.hasPermi('change:allocation:edit')")
    @Log(title = "资产调拨", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbAssetAllocation tbAssetAllocation)
    {
        return toAjax(tbAssetAllocationService.updateTbAssetAllocation(tbAssetAllocation));
    }

    /**
     * 删除资产调拨
     */
    @PreAuthorize("@ss.hasPermi('change:allocation:remove')")
    @Log(title = "资产调拨", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbAssetAllocationService.deleteTbAssetAllocationByIds(ids));
    }
}
